@@ -3,8 +3,7 @@ from .tuanfuncs import pvalues_plot
 from .tuanfuncs import chi_square
 from .tuanfuncs import F_test
 from .tuanfuncs import rsquares_iter
-from .tuanfuncs import quick_rf_importance
-from .tuanfuncs import permutation_importance
+# from .tuanfuncs import quick_rf_importance
 from .tuanfuncs import woe_iv_continuous
 from .tuanfuncs import woe_iv_categ
 from .tuanfuncs import barchart_dict
